==> kmplayer_0.10.5-3.tar.gz: kmplayer-0.10.5/test/actor-mock.cpp <==
#include "../src/actor.h"

using namespace KMPlayer;

ActorAgent::ActorAgent (Control *) {}
ActorAgent::~ActorAgent () {}

Actor::Actor (ActorAgent *, Node *) {}
Actor::~Actor () {}
void Actor::dismiss () {}
Mrl *Actor::mrl () { return NULL; }

MediaInfo::MediaInfo (Node *, ActorAgent::ActorType) {}
MediaInfo::~MediaInfo () {}
bool MediaInfo::wget (const String &) { return false; }
void MediaInfo::killWGet () {}
void MediaInfo::clearData () {}
String MediaInfo::mimetype () { return String(); }
bool MediaInfo::downloading () const { return false; }
void MediaInfo::create () {}
void MediaInfo::jobData (IOJob *, ByteArray &) {}
void MediaInfo::jobResult (IOJob *) {}
void MediaInfo::redirected (IOJob *, const String &) {}
void MediaInfo::ready () {}
bool MediaInfo::readChildDoc () {}

AudioVideoActor::AudioVideoActor (ActorAgent *agent, Node *node) : Actor (agent, node) {}
AudioVideoActor::~AudioVideoActor () {}
bool AudioVideoActor::play () {}
void AudioVideoActor::stop () {}
void AudioVideoActor::pause () {}
void AudioVideoActor::unpause () {}

ImageData::ImageData( const String & img) {}
ImageData::~ImageData() {}
void ImageData::setImage (Image *img) {}
void ImageData::setImage (cairo_surface_t *s, int w, int h) {}
void ImageData::copyImage (Surface *, const SSize &, cairo_surface_t *,
        unsigned int *, CalculatedSizer *) {}

ImageActor::ImageActor (ActorAgent *agent, Node *node, const String &, const ByteArray &)
    : Actor (agent, node) {}
ImageActor::ImageActor (Node *node, ImageDataPtr) : Actor (NULL, node) {}
ImageActor::~ImageActor () {}
bool ImageActor::play () {}
void ImageActor::stop () {}
void ImageActor::pause () {}
void ImageActor::unpause () {}
bool ImageActor::isEmpty () const { return true; }
unsigned ImageActor::render (cairo_surface_t *, ISize) { return 0; }
void ImageActor::sizes (SSize &) {}
void ImageActor::updateRender () {}
bool ImageActor::movieTimer () {}

TextActor::TextActor (ActorAgent *agent, Node *node, const ByteArray &)
    : Actor (agent, node) {}
TextActor::~TextActor () {}
bool TextActor::play () {}
int TextActor::defaultFontSize () { return 0; }

==> kmplayer_0.10.6.900-3.tar.gz: kmplayer-0.10.6.900/test/actor-mock.cpp <==
#include "../src/actor.h"

using namespace KMPlayer;

ActorAgent::ActorAgent (Control *) {}
ActorAgent::~ActorAgent () {}

Actor::Actor (ActorAgent *, Node *) {}
Actor::~Actor () {}
void Actor::dismiss () {}

MediaInfo::MediaInfo (Node *, ActorAgent::ActorType) {}
MediaInfo::~MediaInfo () {}
bool MediaInfo::wget (const String &) { return false; }
void MediaInfo::killWGet () {}
void MediaInfo::clearData () {}
String MediaInfo::mimetype () { return String(); }
bool MediaInfo::downloading () const { return false; }
void MediaInfo::create () {}
void MediaInfo::jobData (IOJob *, ByteArray &) {}
void MediaInfo::jobResult (IOJob *) {}
void MediaInfo::redirected (IOJob *, const String &) {}
void MediaInfo::ready () {}
bool MediaInfo::readChildDoc () {}

AudioVideoActor::AudioVideoActor (ActorAgent *agent, Node *node) : Actor (agent, node) {}
AudioVideoActor::~AudioVideoActor () {}
bool AudioVideoActor::play () {}
void AudioVideoActor::stop () {}
void AudioVideoActor::pause () {}
void AudioVideoActor::unpause () {}
Mrl *AudioVideoActor::sourceMrl () { return NULL; }
void AudioVideoActor::referenceMrl (const String &) {}
void AudioVideoActor::infoMessage (const String &) {}
void AudioVideoActor::readyToPlay (Process *) {}

ImageData::ImageData( const String & img) {}
ImageData::~ImageData() {}
void ImageData::setImage (Image *img) {}
void ImageData::setImage (cairo_surface_t *s, int w, int h) {}
void ImageData::copyImage (Surface *, const SSize &, cairo_surface_t *,
        unsigned int *, CalculatedSizer *) {}

ImageActor::ImageActor (ActorAgent *agent, Node *node, const String &, const ByteArray &)
    : Actor (agent, node) {}
ImageActor::ImageActor (Node *node, ImageDataPtr) : Actor (NULL, node) {}
ImageActor::~ImageActor () {}
bool ImageActor::play () {}
void ImageActor::stop () {}
void ImageActor::pause () {}
void ImageActor::unpause () {}
bool ImageActor::isEmpty () const { return true; }
unsigned ImageActor::render (cairo_surface_t *, ISize) { return 0; }
void ImageActor::sizes (SSize &) {}
void ImageActor::updateRender () {}
bool ImageActor::movieTimer () {}

TextActor::TextActor (ActorAgent *agent, Node *node, const ByteArray &)
    : Actor (agent, node) {}
TextActor::~TextActor () {}
bool TextActor::play () {}
int TextActor::defaultFontSize () { return 0; }
